# estatpy: Project Description

[![PyPI Version](https://img.shields.io/pypi/v/estatpy.svg)](https://pypi.org/pypi/estatpy/)
[![Python Versions](https://img.shields.io/pypi/pyversions/estatpy.svg)](https://pypi.org/pypi/estatpy/)
[![License](https://img.shields.io/pypi/l/estatpy.svg)](https://github.com/poyo46/estatpy/blob/main/LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)

## Installation

estatpy is available on PyPI:

```console
$ pip install estatpy
```

You can also use [poetry](https://python-poetry.org/) to add it to a specific Python project.

```console
$ poetry add estatpy
```
